# Generated by Django 4.2.9 on 2024-01-02 12:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moses', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='customuser',
            old_name='last_phone_number_candidate_confirmation_pin_sent',
            new_name='last_phone_number_confirmation_pins_sent',
        ),
        migrations.RemoveField(
            model_name='customuser',
            name='last_password_reset_sms_sent_at',
        ),
        migrations.RemoveField(
            model_name='customuser',
            name='last_phone_number_confirmation_pin_sent',
        ),
        migrations.RemoveField(
            model_name='customuser',
            name='userpic',
        ),
        migrations.AddField(
            model_name='customuser',
            name='password_reset_code',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='customuser',
            name='password_reset_code_sms_sent_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last password reset code sent at'),
        ),
    ]
